svn commit: r195556 - projects/mesh11s/sys/net80211

Rui Paulo rpaulo at FreeBSD.org
Fri Jul 10 12:02:07 UTC 2009


Author: rpaulo
Date: Fri Jul 10 12:02:05 2009
New Revision: 195556
URL: http://svn.freebsd.org/changeset/base/195556

Log:
  hwmp_newstate(): flush the table on RUN -> !RUN transition.
  
  Sponsored by:	The FreeBSD Foundation

Modified:
  projects/mesh11s/sys/net80211/ieee80211_hwmp.c

Modified: projects/mesh11s/sys/net80211/ieee80211_hwmp.c
==============================================================================
--- projects/mesh11s/sys/net80211/ieee80211_hwmp.c	Fri Jul 10 12:00:21 2009	(r195555)
+++ projects/mesh11s/sys/net80211/ieee80211_hwmp.c	Fri Jul 10 12:02:05 2009	(r195556)
@@ -266,8 +266,8 @@ hwmp_newstate(struct ieee80211vap *vap, 
             __func__, ieee80211_state_name[ostate],
             ieee80211_state_name[nstate], arg);
 
-	/* Flush the table on !INIT -> INIT, e.g. interface down & up */
-	if (nstate != IEEE80211_S_INIT && ostate == IEEE80211_S_INIT)
+	/* Flush the table on RUN -> !RUN, e.g. interface down & up */
+	if (nstate != IEEE80211_S_RUN && ostate == IEEE80211_S_RUN)
 		callout_drain(&hs->hs_roottimer);
 	return 0;
 }


More information about the svn-src-projects mailing list